package jp.co.atmarkit.aws.s3.helper {
import flash.events.MouseEvent;

import jp.co.atmarkit.aws.s3.core.CloseWithDataEvent;
import jp.co.atmarkit.aws.s3.view.KeyRegisterView;
import jp.co.atmarkit.aws.s3.view.MainView;

import mx.controls.Alert;
import mx.core.UIComponent;
import mx.events.MenuEvent;

import org.seasar.akabana.yui.mx.util.PopUpUtil;

    
/**
 * MainHelperクラス。Viewの操作を行います。
 */
public class MainHelper {
    
//--------------------------------------
//  Component
//--------------------------------------

    /** Viewコンポーネントです。 */
    public var view:MainView;
    
//--------------------------------------
//  Constructor
//--------------------------------------

	/**
	 * MainHelper オブジェクトを作成します。
	 */
    public function MainHelper() {
        super();
    }

//--------------------------------------
//  Init
//--------------------------------------
    
    /**
     * Helperに対応するViewを初期化します。
     * 
     * @param Helperに対応するViewです。
     */
    public function initView(view:UIComponent):void {
        this.view = view as MainView;
    }

//--------------------------------------
//  Event Handler Init
//--------------------------------------
    
    /**
     * ListBucketsボタンのクリックハンドラを設定します。
     * 
     * @param handler イベントハンドラです。
     */
    public function initListBucketsButtonHandler(handler:Function):void {
        view.listBucketsButton.addEventListener(MouseEvent.CLICK, handler);
    }
    
    /**
     * メニューバーのクリックハンドラを設定します。
     * 
     * @param handler イベントハンドラです。
     */
    public function initMenuBarHandler(handler:Function):void {
        view.menuBar.addEventListener(MenuEvent.ITEM_CLICK, handler);
    }
    
    /**
     * バケット一覧のダブルクリックハンドラを設定します。
     * 
     * @param handler イベントハンドラです。
     */
    public function initBucketDataGridDoubleClickHandler(handler:Function):void {
        view.bucketDataGrid.addEventListener(MouseEvent.DOUBLE_CLICK, handler);
    }

//--------------------------------------
//  View Manipulation  
//--------------------------------------
    
    /**
     * バケットDataGridのselectedItemを返します。
     * 
     * @return バケットDataGridのselectedItemです。
     */
    public function getBucketDataGridSelectedItem():Object {
        return view.bucketDataGrid.selectedItem;
    }
    
    /**
     * ListBucketsボタンの可否を設定します。
     * 
     * @param enabled ListBucketsボタンの可否です。
     */
    public function enableListBucketsButton(enabled:Boolean):void {
        view.listBucketsButton.enabled = enabled;
    }
    
    /**
     * バケット一覧を設定します。
     * 
     * @param data バケット一覧です。
     */
    public function setBucketList(data:*):void {
        view.bucketDataGrid.dataProvider = data;
    }
    
    /**
     * S3オブジェクト一覧を設定します。
     * 
     * @param data S3オブジェクト一覧です。
     */
    public function setS3ObjectList(data:*):void {
        view.s3ObjectDataGrid.dataProvider = data;
    }
    
    /**
     * バケット名を設定します。
     * 
     * @param value バケット名です。
     */
    public function setBucketName(value:String):void {
        view.bucketNameTextInput.text = value;
    }
    
    /**
     * ストレージアイテム一覧の表示を切り替えます。
     * 
     * @param index ストレージアイテム一覧のインデックスです。
     */
    public function changeStorageItemViewStackSelectedIndex(index:int):void {
        view.storageItemViewStack.selectedIndex = index;
    }
    
    /**
     * 終了アラートを表示します。
     * 
     * @param  alertCloseHandler アラートの閉じるハンドラです。
     */
    public function showCloseApplicationAlert(alertCloseHandler:Function):void {
        Alert.show("終了してよろしいですか?", "警告", Alert.OK | Alert.CANCEL, 
            null, alertCloseHandler);
    }
    
    /**
     * アプリケーションを終了します。
     */
    public function exitApplication():void {
        view.parentApplication.exit();
    }

//--------------------------------------
//  KeyRegisterView
//--------------------------------------

    /**
     * キー登録画面を開きます。
     * 
     * @param closeHandler 閉じるイベントハンドラです。
     */
    public function popUpKeyRegisterView(closeHandler:Function):void {
	    // ユーティリティを用いてポップアップを起動します。
	    var window:KeyRegisterView =
	            PopUpUtil.createPopUp("KeyRegisterView", 
	                                  view.parent, 
	                                  KeyRegisterView, 
	                                  true)
	                                  as KeyRegisterView;

	    window.addEventListener(CloseWithDataEvent.CLOSE, closeHandler);
    }
}
}